Installation
============

Installation and running test examples can be done as follows:

..  code-block:: bash

   pip install dhllinalg 

Or from source

..  code-block::
    
    git clone --recurse-submodules https://github.com/DHL-ASC/DHL-LinAlg.git
    cd DHL-LinAlg
    pip install . 